@@ -38,10 +38,6 @@ namespace
 
     std::random_device dev{};
 
-    // At this time, only floating types are supported, but not long double.
-    using SupportedTypes = std::tuple</*bool, int8_t, uint8_t, int16_t, uint16_t, int32_t, uint32_t, int64_t, uint64_t,*/ float,
-                                      double /*, long double*/>;
-
     using SupportedTypeCodeTypes =
         std::tuple<typecode_to_type<NPY_TYPES::NPY_BOOL>, typecode_to_type<NPY_TYPES::NPY_INT8>,
                    typecode_to_type<NPY_TYPES::NPY_INT16>, typecode_to_type<NPY_TYPES::NPY_INT32>,
@@ -86,48 +82,6 @@ namespace
         }
     }
 
-    struct min_with_nan_passthru_tester
-    {
-        template <typename T>
-        void operator()()
-        {
-            auto const invalid{ riptide::invalid_for_type<T>::value };
-            T const valid{ 0 };
-
-            {
-                auto const result{ riptide::math::min_with_nan_passthru(invalid, valid) };
-                typed_expect<T>(std::is_same_v<T, bool> ? (result == valid) : ! riptide::invalid_for_type<T>::is_valid(result))
-                    << "invalid,valid";
-            }
-            {
-                auto const result{ riptide::math::min_with_nan_passthru(valid, invalid) };
-                typed_expect<T>(std::is_same_v<T, bool> ? (result == valid) : ! riptide::invalid_for_type<T>::is_valid(result))
-                    << "valid,invalid";
-            }
-        }
-    };
-
-    struct max_with_nan_passthru_tester
-    {
-        template <typename T>
-        void operator()()
-        {
-            auto const invalid{ riptide::invalid_for_type<T>::value };
-            T const valid{ 0 };
-
-            {
-                auto const result{ riptide::math::max_with_nan_passthru(invalid, valid) };
-                typed_expect<T>(std::is_same_v<T, bool> ? (result == valid) : ! riptide::invalid_for_type<T>::is_valid(result))
-                    << "invalid,valid";
-            }
-            {
-                auto const result{ riptide::math::max_with_nan_passthru(valid, invalid) };
-                typed_expect<T>(std::is_same_v<T, bool> ? (result == valid) : ! riptide::invalid_for_type<T>::is_valid(result))
-                    << "valid,invalid";
-            }
-        }
-    };
-
     constexpr NPY_TYPES get_output_typecode(NPY_TYPES const typecode_in, REDUCE_FUNCTIONS const fn)
     {
         if (fn >= REDUCE_ARGMAX && fn <= REDUCE_NANARGMAX)
@@ -818,9 +772,6 @@ namespace
 
     suite reduce_ops = []
     {
-        "min_with_nan_passthru"_test = min_with_nan_passthru_tester{} | SupportedTypes{};
-        "max_with_nan_passthru"_test = max_with_nan_passthru_tester{} | SupportedTypes{};
-
         "reduce_sum_valid"_test = reduce_tests<REDUCE_SUM>::test<test_case_id::VALID>{} | SupportedTypeCodeTypes{};
         //badimpl//"reduce_sum_mixed"_test = reduce_tests<REDUCE_SUM>::test<test_case_id::MIXED>{} | SupportedTypeCodeTypes{};
         "reduce_sum_invalid"_test = reduce_tests<REDUCE_SUM>::test<test_case_id::VALID>{} | SupportedTypeCodeTypes{};
